#====Load Packages====
library(jpeg) #read images and extract channel values



#====Set up directories to read in photos====
dir = paste0("../IR Lichen/Myvatn Lichen IR/Cropped Lichen Photos") 
files = list.files(dir) #get the name for each file



#get the number of photos
nphotos = length(files)

#create data frame
x = data.frame(file=rep(NA, nphotos), site=NA, plot = NA, lichen = NA, section = NA, ENDVI=NA, ENDVI_min=NA, ENDVI_max=NA, height = NA, width = NA) 


#for loop to apply this to each photo
for(i in 1:nphotos){
		filename = files[i] #get file name for the ith file
		
		x$file[i] = filename #indicate file name
		#using informative filenames to deterimine site, lichen id and section
		x$site[i] = strsplit(substr(filename, 1, nchar(filename)-5), "_")[[1]][1]
		x$plot[i] = strsplit(substr(filename, 1, nchar(filename)-5), "_")[[1]][2]
		x$lichen[i] = strsplit(substr(filename, 1, nchar(filename)-5), "_")[[1]][3]
		x$section[i] = strsplit(substr(filename, 1, nchar(filename)-5), "_")[[1]][4]
		
		
	
		d = readJPEG(paste0(dir,"/",filename)) #read in photo
		

		#get dimensions of photo
		xright = dim(d)[2]
		xleft = 1
		ytop = dim(d)[1]
		ybottom = 1
		

		#calculate NDVI
		#here we calculate ENDVI which is ((NIR+Green)-2*(blue))/((NIR+Green)+2blue)
		ENDVI = ((d[, , 1] + d[,,2]) - 2*d[,,3])/((d[, , 1] + d[,,2]) + 2*d[,,3])

		#fill in the NDVI columns
		x$ENDVI[i] = mean(ENDVI, na.rm = TRUE)
		x$ENDVI_min[i] = min(ENDVI, na.rm = TRUE)
		x$ENDVI_max[i] = max(ENDVI, na.rm = TRUE)
		x$height[i] = ytop
		x$width [i] = xright

	
}


#write table with the output
write.table(x, paste0("../Data/Lichen_IR.csv"), sep=",", row.names=F)
